@@ -290,7 +290,12 @@ def api_external_get_mo(request):
 
         token = request.token
 
-        all_mo = get_parameter(request, "all"):
+        all_mo = 0
+        try:
+            all_mo = get_parameter(request, "all")
+            all_mo = int(all_mo)
+        except Exception:
+            pass
 
         try:
             recorder = \
@@ -302,7 +307,9 @@ def api_external_get_mo(request):
             res["response"]=response
             return json_response(res)
 
-        if all_mo:
+
+
+        if all_mo == 1:
             recordings_list = Recording.objects.iterator()
         else:
             recordings_list = Recording.objects\
@@ -315,16 +322,18 @@ def api_external_get_mo(request):
                 logger.debug("Getting profiles for %s : %s" % (r,r.profiles_json))
                 for p in profiles:
                     response.append(p["destination"])
-                metadatas = json.logger(r.metadata_json)
-                logger.debug("Getting smil for %s : %s" % (r,r.metadata_json))
-                for m in metadatas:
-                    try:
-                        k = m.keys()[0]
-                        v = m.value()[0]
-                        if k == "smil":
-                            response.append(v)
-                    except Exception:
-                        pass
+                metadatas = json.loads(r.metadata_json)
+                if all_mo == 1:
+                    logger.debug("Getting smil for %s : %s" % (r,r.metadata_json))
+                    for m in metadatas:
+                        try:
+                            k = m.keys()[0]
+                            v = m.values()[0]
+                            if k == "smil":
+                                response.append(v)
+                        except Exception,e:
+                            logger.critical(e)
+                            pass
 
             except Exception as e:
                 logger.error( "Exception occurs getting profiles for %s: %s"% (r,e))
@@ -455,3 +464,5 @@ recording_job=recording_job,key=k).update(value=v.strip())
 
 
 
+
+
